package implement

import (
	"code.fnuoos.com/EggPlanet/egg_models.git/src/dao"
	"code.fnuoos.com/EggPlanet/egg_models.git/src/model"
	zhios_order_relate_utils "code.fnuoos.com/EggPlanet/egg_models.git/utils"
	zhios_order_relate_logx "code.fnuoos.com/EggPlanet/egg_models.git/utils/logx"
	"fmt"
	"xorm.io/xorm"
)

func NewAdvertisingCallbackDb(engine *xorm.Engine) dao.AdvertisingCallbackDao {
	return &AdvertisingCallbackDb{Db: engine}
}

type AdvertisingCallbackDb struct {
	Db *xorm.Engine
}

func (a AdvertisingCallbackDb) FindAdvertisingCallbackAndTotal(page, limit, amount, uid, startTime, endTime, platform, types string) (*[]model.AdvertisingCallback, int64, error) {
	var m []model.AdvertisingCallback
	sess := a.Db.Where("1=1")
	if amount != "" {
		sess.And("amount<=?", zhios_order_relate_utils.StrToFloat64(amount))
	}
	if uid != "" {
		sess.And("uid=?", uid)
	}
	if platform != "" {
		sess.And("platform=?", platform)
	}
	if types != "" {
		sess.And("type=?", types)
	}
	if startTime != "" {
		sess.And("create_at>=?", startTime)
	}
	if endTime != "" {
		sess.And("create_at<=?", endTime)
	}
	start := (zhios_order_relate_utils.StrToInt(page) - 1) * zhios_order_relate_utils.StrToInt(limit)
	count, err := sess.Limit(zhios_order_relate_utils.StrToInt(limit), start).OrderBy("id desc").FindAndCount(&m)
	if err != nil {
		return nil, count, zhios_order_relate_logx.Error(err)
	}
	return &m, count, nil
}

func (a AdvertisingCallbackDb) AdvertisingCallbackCount(uid, startTime, endTime, typePrefix string) (int64, error) {
	sess := a.Db.Where("1=1")
	if uid != "" {
		sess.And("uid=?", uid)
	}
	if typePrefix != "" {
		types := fmt.Sprintf("type LIKE '%s'", typePrefix+"%")
		sess.And(types)
	}
	if startTime != "" {
		sess.And("create_at>=?", startTime)
	}
	if endTime != "" {
		sess.And("create_at<=?", endTime)
	}
	count, err := sess.Count(&model.AdvertisingCallback{})
	if err != nil {
		return 0, err
	}
	return count, nil
}

func (a AdvertisingCallbackDb) AdvertisingCallbackDeleteByDateByPage(date string, limit int) (int64, error) {
	affected, err := a.Db.Where("create_at < ?", date).Limit(limit).Delete(&model.AdvertisingCallback{})
	if err != nil {
		return 0, zhios_order_relate_logx.Error(err.Error())
	}
	return affected, nil
}
